@@ -15,7 +15,10 @@ Geo::WebService::Elevation::USGS - Elevation queries against USGS web services.
 
 Version 0.106_01 changes the default value of the C<'compatible'>
 attribute to C<0> (i.e. false). With version 0.108_01, the
-first attempt to modify this attribute will warn.
+first attempt to modify this attribute will warn. With version
+0.110_01, all attempts to modify this attribute will warn,
+and six months after the release of this version, any attempt to modify
+it will become fatal.
 
 The GIS data web service this module was originally based on has gone
 the way of the dodo. This release uses the NED service, which is similar
@@ -70,7 +73,7 @@ In the meantime you can suppress the warnings with
 
 The C<compatible> attribute is deprecated as of release 0.104_01. As of
 release 0.106_01 it will warn when set true. In the first
-release after September 1 2018 it will warn on any use. Six months after
+release after March 1 2019 it will warn on any use. Six months after
 that, it will become a fatal error to use it.
 
 =head1 DESCRIPTION
@@ -124,10 +127,10 @@ use JSON;
 use LWP::UserAgent;
 use Scalar::Util 1.10 qw{ blessed looks_like_number };
 
-our $VERSION = '0.108_01';
+our $VERSION = '0.110_01';
 
 use constant BEST_DATA_SET => -1;
-use constant USGS_URL => 'http://nationalmap.gov/epqs/pqs.php';
+use constant USGS_URL => 'http://ned.usgs.gov/epqs/pqs.php';
 
 use constant ARRAY_REF	=> ref [];
 use constant CODE_REF	=> ref sub {};
@@ -194,6 +197,7 @@ sub new {
 	timeout	=> 30,
 	trace	=> undef,
 	units	=> 'FEET',
+	usgs_url	=> $ENV{GEO_WEBSERVICE_ELEVATION_USGS_URL} || USGS_URL,
 	use_all_limit => 5,
     };
     bless $self, $class;
@@ -216,6 +220,7 @@ my %mutator = (
     timeout	=> \&_set_integer_or_undef,
     trace	=> \&_set_literal,
     units	=> \&_set_literal,
+    usgs_url	=> \&_set_literal,
     use_all_limit => \&_set_integer,
 );
 
@@ -496,7 +501,7 @@ sub _set_unsigned_integer {
 	attribute	=> {
 	    dflt	=> sub { return },
 	    item	=> {
-		compatible	=> 1,
+		compatible	=> 2,
 		default_ns	=> 2,
 		proxy		=> 2,
 		source		=> 2,
@@ -703,7 +708,7 @@ sub _request {
 	: 'Feet';
     $arg{output}	= 'json';
 
-    my $uri = URI->new( USGS_URL );
+    my $uri = URI->new( $self->get( 'usgs_url' ) );
     $uri->query_form( \%arg );
     my $rqst = HTTP::Request::Common::GET( $uri );
 
@@ -960,6 +965,16 @@ entries at all, no matter how many it has.
 
 The default is 5, which was chosen based on timings of the two methods.
 
+=head3 usgs_url
+
+This attribute specifies the URL to query. Under normal circumstances
+you will not need to change this, but maybe it can get you going again
+if the USGS moves the service.
+
+The default is the value of environment variable 
+C<GEO_WEBSERVICE_ELEVATION_USGS_URL>. If that is undefined, the default
+is C<http://ned.usgs.gov/epqs/pqs.php>.
+
 =head1 ACKNOWLEDGMENTS
 
 The author wishes to acknowledge the following individuals and groups.
@@ -984,7 +999,7 @@ Thomas R. Wyant, III; F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008-2018 Thomas R. Wyant, III
+Copyright (C) 2008-2019 Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
